/* Generated by Nim Compiler v1.4.2 */
/*   (c) 2020 Andreas Rumpf */
/* The generated code is subject to the original license. */
#define NIM_INTBITS 64

/* section: NIM_merge_HEADERS */

#include "nimbase.h"
#include <string.h>
#include <stdio.h>
#include <setjmp.h>
#include <stdlib.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix

/* section: NIM_merge_FRAME_DEFINES */
#define nimfr_(x, y)
#define nimln_(x, y)

/* section: NIM_merge_FORWARD_TYPES */
typedef struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw;
typedef struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyObject_HSlice__9a7LZzxhxaoaVRy8OcVBd9cg tyObject_HSlice__9a7LZzxhxaoaVRy8OcVBd9cg;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw tyObject_Target__9abOl5DLX8suLujOaHSvGzw;
typedef struct tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg;
typedef struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A;
typedef struct tySequence__tNFrR3kRuS1FSwuiLGoSSA tySequence__tNFrR3kRuS1FSwuiLGoSSA;
typedef struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ tySequence__Zi9cGbCWofbtABoHJ5RbLNQ;
typedef struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw tySequence__pK3qSsBZwdXd6qyUMkd5Jw;
typedef struct tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ;
typedef struct tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig;
typedef struct tyTuple__z822nu9bFF1AlQnLrHjdwpA tyTuple__z822nu9bFF1AlQnLrHjdwpA;
typedef struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw;
typedef struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA;
typedef struct Exception Exception;
typedef struct RootObj RootObj;
typedef struct tySequence__uB9b75OUPRENsBAu4AnoePA tySequence__uB9b75OUPRENsBAu4AnoePA;
typedef struct TSafePoint TSafePoint;
typedef struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g;
typedef struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w;
typedef struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ;
typedef struct tyObject_GcStack__7fytPA5bBsob6See21YMRA tyObject_GcStack__7fytPA5bBsob6See21YMRA;
typedef struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg;
typedef struct tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ;
typedef struct tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg;
typedef struct tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw;
typedef struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA;
typedef struct tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw;
typedef struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw;
typedef struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg;
typedef struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyTuple__ujsjpB2O9cjj3uDHsXbnSzg;
typedef struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg;
typedef struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ;
typedef struct tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg;
typedef struct tyObject_ESuggestDone__cDtWY9cE7zf8BAC5QcEZZkQ tyObject_ESuggestDone__cDtWY9cE7zf8BAC5QcEZZkQ;
typedef struct tyObject_ValueError__yoNlBGx0D2tRizIdhQuENw tyObject_ValueError__yoNlBGx0D2tRizIdhQuENw;
typedef struct tyObject_CatchableError__qrLSDoe2oBoAqNtJ9badtnA tyObject_CatchableError__qrLSDoe2oBoAqNtJ9badtnA;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg;
typedef struct tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA;

/* section: NIM_merge_TYPES */
struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU8 tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
typedef NU8 tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
typedef NU8 tyEnum_ForegroundColor__ez9ah4IgQc0AbdW68acioDg;
typedef NU8 tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA;
struct tyObject_HSlice__9a7LZzxhxaoaVRy8OcVBd9cg {
tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w a;
tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w b;
};
typedef NU8 tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A;
typedef NU8 tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A kind;
tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
typedef NU8 tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ;
struct TNimNode {
tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
typedef NU8 tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g;
typedef NU8 tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag;
typedef NU8 tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ;
struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw {
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag targetCPU;
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag hostCPU;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ targetOS;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU32 tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg;
typedef NU64 tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw;
typedef NU8 tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA;
struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA errorOutputs;
tySequence__tNFrR3kRuS1FSwuiLGoSSA* msgContext;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastError;
tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA filenameToIndexTbl;
tySequence__Zi9cGbCWofbtABoHJ5RbLNQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw;
typedef NU8 tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw;
typedef NU8 tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ;
typedef NU8 tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ;
struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU16 tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ;
typedef NU8 tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA;
typedef NU8 tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ;
typedef NU8 tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA;
typedef NU8 tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg[9];
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* result, void* ClE_0);
void* ClE_0;
} tyProc__YD0MR9bJ2x4beJkZdnjXN9cA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* msg, tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA severity, void* ClE_0);
void* ClE_0;
} tyProc__oL9coyIA2VDTGdUcur9aL9bew;
struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw {
tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g backend;
tyObject_Target__9abOl5DLX8suLujOaHSvGzw target;
NI linesCompiled;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw globalOptions;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* macrosToExpand;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* arcToExpand;
tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A m;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw cmd;
tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw selectedGC;
tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ exc;
NI verbosity;
NI numberOfProcessors;
NimStringDesc* evalExpr;
NF lastCmdTime;
tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ symbolFiles;
tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ features;
tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA cCompiler;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg modifiedyNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg cmdlineNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg foreignPackageNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg notes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg warningAsErrors;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* configVars;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* symbols;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* dllOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* moduleOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
NIM_BOOL lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__pK3qSsBZwdXd6qyUMkd5Jw* toCompile;
tyProc__YD0MR9bJ2x4beJkZdnjXN9cA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__oL9coyIA2VDTGdUcur9aL9bew structuredErrorHook;
NimStringDesc* cppCustomNamespace;
tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig* vmProfileData;
};
struct tyTuple__z822nu9bFF1AlQnLrHjdwpA {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q Field0;
NimStringDesc* Field1;
};
typedef N_CLOSURE_PTR(void, TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_4) (tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* msg, tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA severity);
typedef NimStringDesc* tyArray__nHXaesL0DJZHyVS07ARPRA[1];
typedef NimStringDesc* tyArray__24KAM9afIUgUaqBaEBB6r9bg[3];
typedef NU8 tyEnum_FilenameOption__PR85MOw9bZL5JFJQSb26org;
struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
typedef NU8 tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw;
typedef N_CLOSURE_PTR(void, TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_13) (NimStringDesc* output);
typedef NU8 tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA;
typedef NU16 tySet_tyEnum_Style__NXKayqTLMsAibFwNceBlpA;
typedef NU8 tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg;
typedef NimStringDesc* tyArray__z9cqFgHiS9ahHOXLmNWEBvBg[84];
typedef N_CLOSURE_PTR(void, TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_19) (tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* msg, tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA severity);
typedef NimStringDesc* tyArray__sMpvt1sOxOJ3LFGulnbeMQ[4];
typedef N_CLOSURE_PTR(void, TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_21) (NimStringDesc* output);
typedef NU8 tySet_tyEnum_MsgFlag__BzRTaQ6LrPDZKEKt9bswkOQ;
typedef NU8 tyEnum_MsgFlag__BzRTaQ6LrPDZKEKt9bswkOQ;
typedef N_CLOSURE_PTR(void, TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_22) (NimStringDesc* output);
struct RootObj {
TNimType* m_type;
};
struct Exception {
  RootObj Sup;
Exception* parent;
NCSTRING name;
NimStringDesc* message;
tySequence__uB9b75OUPRENsBAu4AnoePA* trace;
Exception* up;
};
struct TSafePoint {
TSafePoint* prev;
NI status;
jmp_buf context;
};
typedef NU8 tyEnum_FileMode__ZJfK20XeZ9bv2j1pZjw9aswg;
struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__7fytPA5bBsob6See21YMRA {
void* bottom;
};
struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w {
NI len;
NI cap;
tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g** d;
};
typedef tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ* tyArray__SPr7N6UKfuF549bNPiUvSRw[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* tyArray__N1u1nqOgmuJN9cSZrnMHgOQ[32];
typedef tyArray__N1u1nqOgmuJN9cSZrnMHgOQ tyArray__B6durA4ZCi1xjJvRtyYxMg[24];
typedef tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw* tyArray__lh2A89ahMmYg9bCmpVaplLbA[256];
struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA {
tyArray__lh2A89ahMmYg9bCmpVaplLbA data;
};
typedef tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* tyArray__0aOLqZchNi8nWtMTi8ND8w[2];
struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw {
tyArray__0aOLqZchNi8nWtMTi8ND8w link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg {
tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* Field0;
NI Field1;
};
typedef tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyArray__LzOv2eCDGiceMKQstCLmhw[30];
struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg {
NI len;
tyArray__LzOv2eCDGiceMKQstCLmhw chunks;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg* next;
};
struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg {
NI minLargeObj;
NI maxLargeObj;
tyArray__SPr7N6UKfuF549bNPiUvSRw freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__B6durA4ZCi1xjJvRtyYxMg matrix;
tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA chunkStarts;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* root;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* deleted;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* last;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw bottomData;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg heapLinks;
};
struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ {
NI counter;
NI max;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg* head;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg** data;
};
struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ {
tyObject_GcStack__7fytPA5bBsob6See21YMRA stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w zct;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w decStack;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tempStack;
NI recGcLock;
tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg region;
tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg stat;
tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ marked;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w additionalRoots;
NI gcThreadId;
};
typedef N_CLOSURE_PTR(void, TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_28) (NimStringDesc* output);
typedef NimStringDesc* tyArray__Re75IspeoxXy2oCZHwcRrA[2];
typedef N_CLOSURE_PTR(void, TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_32) (NimStringDesc* output);
struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA {
  RootObj Sup;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* left;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* right;
NI L;
NimStringDesc* data;
};
typedef N_CLOSURE_PTR(void, TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_40) (NimStringDesc* output);
struct tyObject_CatchableError__qrLSDoe2oBoAqNtJ9badtnA {
  Exception Sup;
};
struct tyObject_ValueError__yoNlBGx0D2tRizIdhQuENw {
  tyObject_CatchableError__qrLSDoe2oBoAqNtJ9badtnA Sup;
};
struct tyObject_ESuggestDone__cDtWY9cE7zf8BAC5QcEZZkQ {
  tyObject_ValueError__yoNlBGx0D2tRizIdhQuENw Sup;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA;
struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA flags;
NimStringDesc* customArgs;
};
struct tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA {
NCSTRING procname;
NI line;
NCSTRING filename;
};

/* section: NIM_merge_SEQ_TYPES */
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw data[SEQ_DECL_SIZE];
};
struct tySequence__tNFrR3kRuS1FSwuiLGoSSA {
  TGenericSeq Sup;
  tyTuple__z822nu9bFF1AlQnLrHjdwpA data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw {
  TGenericSeq Sup;
  tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg data[SEQ_DECL_SIZE];
};
struct tySequence__uB9b75OUPRENsBAu4AnoePA {
  TGenericSeq Sup;
  tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA data[SEQ_DECL_SIZE];
};

/* section: NIM_merge_PROC_HEADERS */
static N_INLINE(NIM_BOOL, contains__C6zknI9aj0qzb4XAbwM6y9cQsystem)(tyObject_HSlice__9a7LZzxhxaoaVRy8OcVBd9cg s, tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w value);
static N_INLINE(tyObject_HSlice__9a7LZzxhxaoaVRy8OcVBd9cg, dotdot___N3IU9cJ5UjABfbcVFvMuhrQsystem)(tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w a, tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w b);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, reprEnum)(NI e, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(void, writeContext__qseR1pyA8fYS6Wwflt2zAQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastinfo);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___59bygf5b7AsTVb9a1lVM66oA)(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q a, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q b);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatVarargs)(NimStringDesc* formatstr, NimStringDesc** a, NI aLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, concat__9brDhFFC9aYh4TjJmoPfzOdw)(NimStringDesc** strings, NI stringsLen_0);
N_NIMCALL(NimStringDesc*, rawNewString)(NI cap);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__i80o3k0SgEI5gTRCzYdyWAsystem)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
static N_INLINE(NimStringDesc*, toFileLineCol__WM0LdwjY884aJ9cup7BS2vwmsgs)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toMsgFilename__eX9aCxa5NfPq9alDDS1zYbvw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NI32 info);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toFilenameOption__hCtp6lwFVPBOAIlYyXBiuA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NI32 fileIdx, tyEnum_FilenameOption__PR85MOw9bZL5JFJQSb26org opt);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toFullPath__VW1RaR1l9c9bPnJxr1KuvIrg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NI32 fileIdx);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toProjPath__VW1RaR1l9c9bPnJxr1KuvIrg_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NI32 fileIdx);
N_LIB_PRIVATE N_NIMCALL(NI, nsuCountString)(NimStringDesc* s, NimStringDesc* sub, NIM_BOOL overlapping);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, noslastPathPart)(NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(void, addInt__mftMOxbyu0h4yByfs3sqjA)(NimStringDesc** result, NI64 x);
N_LIB_PRIVATE N_NIMCALL(void, write__PArlm09bKklm2BLsCg6YtaA)(FILE* f, NimStringDesc* s);
static N_INLINE(void, writeLine__45Em82MGXqv9biomV0DEbSgio)(FILE* f, NimStringDesc** x, NI xLen_0);
N_LIB_PRIVATE N_NIMCALL(void, flushFile__fU6ZlJAtQ9bre04EDZLdGsA_2)(FILE* f);
N_LIB_PRIVATE N_NIMCALL(void, setStyle__y8lW2LrW2n5ZHaxH9bAf4WA)(FILE* f, tySet_tyEnum_Style__NXKayqTLMsAibFwNceBlpA style);
N_LIB_PRIVATE N_NIMCALL(void, resetAttributes__6J8xlU57R8cS9bLzTS89aM5g)(FILE* f);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasWarn__zh6OC34d9cPUHXjZ4qVA9bkw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg note);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasHint__zh6OC34d9cPUHXjZ4qVA9bkw_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg note);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getMessageStr__bApVJwLsexHv26MjGbKUvQ)(tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w msg, NimStringDesc* arg);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatOpenArray)(NimStringDesc* formatstr, NimStringDesc** a, NI aLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, msgKindToString__pY9bbQrdTPzM2HGfayOe6eQ)(tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w kind);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatSingleElem)(NimStringDesc* formatstr, NimStringDesc* a);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, ignoreMsgBecauseOfIdeTools__wvc4V6zIgESu6cpPmGz9abA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w msg);
N_LIB_PRIVATE N_NIMCALL(void, msgWrite__NefEsy9c5k5U9cqqVIWMbpKg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(void, setForegroundColor__vJutklhcnQq9akCXxcuSHAg)(FILE* f, tyEnum_ForegroundColor__ez9ah4IgQc0AbdW68acioDg fg, NIM_BOOL bright);
N_LIB_PRIVATE N_NIMCALL(void, writeSurroundingSrc__9aRUSlnze6Qb3IwHkkQ9bv6g)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(void, msgWriteln__PO49anyWCbe63GYNOs9cVuvg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* s, tySet_tyEnum_MsgFlag__BzRTaQ6LrPDZKEKt9bswkOQ flags);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, sourceLine__b49bYNvmBdG6RP9cHaZGFhvQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q i);
N_LIB_PRIVATE N_NIMCALL(NI, numLines__x9aqxDAtGd57HztdSIhXLtQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NI32 fileIdx);
static N_INLINE(void, pushSafePoint)(TSafePoint* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toFullPathConsiderDirty__fr10i3QiqDDNG5EqWBCesA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NI32 fileIdx);
static N_INLINE(NIM_BOOL, isEmpty__kPpSxL0H5sJ9a6ujvdQ0QVQpathutils)(NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(FILE*, open__cb1k9citqyT9a9brBSJAz8pkg)(NimStringDesc* filename, tyEnum_FileMode__ZJfK20XeZ9bv2j1pZjw9aswg mode, NI bufSize);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, readLine__FbqDHP9bu7nqCh9c04dnSOxw)(FILE* f, NimStringDesc** line);
N_LIB_PRIVATE N_NIMCALL(void, addSourceLine__9cPswkSBuJ0YLnDEBw6Iieg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NI32 fileIdx, NimStringDesc* line);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y);
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr);
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y);
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__Y66tOYFjgwJ0k4aLz4bc0Q)(tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w* s, tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyStringRC1)(NimStringDesc* src);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
static N_INLINE(void, popSafePoint)(void);
N_LIB_PRIVATE N_NIMCALL(void, close__fU6ZlJAtQ9bre04EDZLdGsA_3)(FILE* f);
N_LIB_PRIVATE N_NIMCALL(void, nimLeaveFinally)(void);
N_LIB_PRIVATE N_NIMCALL(void, reraiseException)(void);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isObj)(TNimType* obj, TNimType* subclass);
static N_INLINE(Exception*, nimBorrowCurrentException)(void);
static N_INLINE(void, popCurrentException)(void);
static N_INLINE(NimStringDesc*, spaces__rssDy7zs9cDeoYTeCoIy0Wgstrutils)(NI n);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuRepeatChar)(NIM_CHAR c, NI count);
static N_INLINE(void, appendChar)(NimStringDesc* dest, NIM_CHAR c);
static N_INLINE(NimStringDesc*, toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info);
N_LIB_PRIVATE N_NIMCALL(void, handleError__T2cS0vBHloueESngIcrNPg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w msg, tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw eh, NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(void, log__tRbCZ4fGDe9a36bXIedwnwQ)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, open__gq12VLhVO0NBzUTnGgz4nw)(FILE** f, NimStringDesc* filename, tyEnum_FileMode__ZJfK20XeZ9bv2j1pZjw9aswg mode, NI bufSize);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, slash___gEyhbzZ1UcxyenWRLJRXNQ)(NimStringDesc* head, NimStringDesc* tail);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosgetHomeDir)(void);
N_LIB_PRIVATE N_NIMCALL(void, quit__Fedq6hIgzK5Ezo80jU9aqAg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w msg);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, stackTraceAvailable__xiAaEKYdoaDLIIbJ78BqmQ)(void);
N_LIB_PRIVATE N_NIMCALL(void, writeStackTrace__amVlU9ajqZ06ujoesRBHcDg_4)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, createDocLink__pWiLD3R2s41obcTDlPhj9cA)(NimStringDesc* urlSuffix);
N_LIB_PRIVATE N_NOINLINE(void, raiseRecoverableError__5jd5IdwI3N06CaI2zjEQsQ)(NimStringDesc* msg);
N_LIB_PRIVATE N_NIMCALL(NI32, fileInfoIdx__Eu6qwnWjBAlxk5Kd4AsfYg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* filename, NIM_BOOL* isKnownFile);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, canonicalizePath__9bhgFqdEZM7DoX7p3U69bQEg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* path);
static N_INLINE(void, shallow__cnzwaZQQIa73ryXE31wijQsystem)(NimStringDesc** s);
N_NIMCALL(NimStringDesc*, mnewString)(NI len);
N_LIB_PRIVATE N_NIMCALL(void, forceCopy__9aS5wD8MwJoemnVo59bh54Sg)(NimStringDesc** result, NimStringDesc* a);
N_LIB_PRIVATE N_NIMCALL(void, canonicalCase__ieSCOeB9alirM2uC0jUt1Dg)(NimStringDesc** path);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__V2bna9aem30Wfb1MT9bSnPzQ)(tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA t, NimStringDesc* key);
N_LIB_PRIVATE N_NIMCALL(NI32*, X5BX5D___cYD9bwEY2FvxLm9bWq5KUhtA)(tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA* t, NimStringDesc* key);
N_LIB_PRIVATE N_NIMCALL(void, newFileInfo__H9aV055mSUDR4HgT7SX79aqA)(NimStringDesc* fullPath, NimStringDesc* projPath, tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw* Result);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosextractFilename)(NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, makeCString__vQJydtKy4Nf6bXPYtbmjtg)(NimStringDesc* s);
static N_INLINE(NF, toFloat__y1Fm9aHmxw9bS2jir137Fu5gsystem)(NI i);
N_LIB_PRIVATE N_NIMCALL(void, toCChar__JTr4d3QfIoJwmoCY9bN9adqQ)(NIM_CHAR c, NimStringDesc** result);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, addChar)(NimStringDesc* s, NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuToOctal)(NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(void, add__IM4kcMNkkOLJtqdEqSxR8A)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** a, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, rope__yShmEg9cffWxI7s5XzEKBow)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, relativeTo__zjjWvxBunys9bbBJHoqyLyQ)(NimStringDesc* fullPath, NimStringDesc* baseFilename, NIM_CHAR sep);
N_LIB_PRIVATE N_NIMCALL(void, genericAssign)(void* dest, void* src, TNimType* mt);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___anizD9c0GXTQTVVON49cli6g)(tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA* t, NimStringDesc* key, NI32 val);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, setLengthSeqV2)(TGenericSeq* s, TNimType* typ, NI newLen);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__Q6JNH4uRwLyZrj0dJakHew)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w msg, NimStringDesc* arg, tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
N_LIB_PRIVATE N_NIMCALL(void*, newObj)(TNimType* typ, NI size);
N_LIB_PRIVATE N_NIMCALL(void, raiseExceptionEx)(Exception* e, NCSTRING ename, NCSTRING procname, NCSTRING filename, NI line);
static N_INLINE(NIM_BOOL, lteqpercent___hPljn3JCDQ00ua1R07X9bxQ_2system)(NI x, NI y);

/* section: NIM_merge_DATA */
extern TNimType NTI__29cbg2fC1z5iM1PAI28kR5w_;
static NIM_CONST tyProc__oL9coyIA2VDTGdUcur9aL9bew TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_2 = {NIM_NIL,NIM_NIL};
STRING_LITERAL(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_3, "template/generic instantiation from here", 40);
STRING_LITERAL(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_5, "template/generic instantiation of `$1` from here", 48);
STRING_LITERAL(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_6, "command line", 12);
STRING_LITERAL(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_7, "\?\?\?", 3);
STRING_LITERAL(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_8, "..", 2);
STRING_LITERAL(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_9, "(", 1);
STRING_LITERAL(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_10, ", ", 2);
STRING_LITERAL(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_11, ")", 1);
STRING_LITERAL(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_12, " ", 1);
STRING_LITERAL(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_14, "\012", 1);
STRING_LITERAL(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_15, "Error: ", 7);
extern NIM_CONST tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg;
STRING_LITERAL(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_16, "Warning: ", 9);
STRING_LITERAL(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_17, "Hint: ", 6);
extern NIM_CONST tyArray__z9cqFgHiS9ahHOXLmNWEBvBg MsgKindToStr__toc2ERobyllo49aZhx0umtQ;
STRING_LITERAL(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_18, " [$1]", 5);
STRING_LITERAL(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_20, ".", 1);
STRING_LITERAL(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_23, "  ", 2);
extern TNimType NTI__sM4lkSb7zS6F7OVMvW9cffQ_;
extern TNimType NTI__iLZrPn9anoh9ad1MmO0RczFw_;
STRING_LITERAL(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_26, " compiler msg initiated here", 28);
STRING_LITERAL(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_27, "MsgOrigin", 9);
STRING_LITERAL(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_29, "nimsuggest.log", 14);
STRING_LITERAL(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_30, "No stack traceback available\012To create a stacktrace, rerun comp"
"ilation with \'./koch temp $1 <file>\', see $2 for details", 119);
STRING_LITERAL(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_31, "intern.html#debugging-the-compiler", 34);
STRING_LITERAL(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_33, "Warnings:", 9);
STRING_LITERAL(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_34, "  [$1] $2", 9);
STRING_LITERAL(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_35, "x", 1);
STRING_LITERAL(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_36, "Hints:", 6);
extern TNimType NTI__BeJgrOdDsczOwEWOZbRfKA_;
STRING_LITERAL(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_38, "\"", 1);
STRING_LITERAL(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_39, "\"\012\"", 3);
extern TNimType NTI__Zi9cGbCWofbtABoHJ5RbLNQ_;
extern TNimType NTI__GE3hAakXKOEpch4ap3zXAw_;
N_LIB_PRIVATE NIM_CONST tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q gCmdLineInfo__yhfh3fjBy4h9bf6keLoh9aXQ = {((NU16) 1), ((NI16) 1), ((NI32) -3)}
;
extern TNimType NTI__tNFrR3kRuS1FSwuiLGoSSA_;
extern TNimType NTI__q2mvqo4oBiq6VrjsaIw7rg_;
extern TNimType NTI__cDtWY9cE7zf8BAC5QcEZZkQ_;
STRING_LITERAL(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_41, "suggest done", 12);

/* section: NIM_merge_VARS */
extern TSafePoint* excHandler__rqLlY5bs9atDw2OXYqJEn5g;
extern TSafePoint* excHandler__rqLlY5bs9atDw2OXYqJEn5g;
extern tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ gch__IcYaEuuWivYAS86vFMTS3Q;
extern TSafePoint* excHandler__rqLlY5bs9atDw2OXYqJEn5g;
extern TSafePoint* excHandler__rqLlY5bs9atDw2OXYqJEn5g;
extern Exception* currException__9bVPeDJlYTi9bQApZpfH8wjg;
extern Exception* currException__9bVPeDJlYTi9bQApZpfH8wjg;
extern Exception* currException__9bVPeDJlYTi9bQApZpfH8wjg;

/* section: NIM_merge_PROCS */
static N_INLINE(NIM_BOOL, contains__C6zknI9aj0qzb4XAbwM6y9cQsystem)(tyObject_HSlice__9a7LZzxhxaoaVRy8OcVBd9cg s, tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w value) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = (s.a <= value);
	if (!(T1_)) goto LA2_;
	T1_ = (value <= s.b);
	LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(void, nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory(p, ((int) 0), size);
}
static N_INLINE(tyObject_HSlice__9a7LZzxhxaoaVRy8OcVBd9cg, dotdot___N3IU9cJ5UjABfbcVFvMuhrQsystem)(tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w a, tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w b) {
	tyObject_HSlice__9a7LZzxhxaoaVRy8OcVBd9cg result;
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__9a7LZzxhxaoaVRy8OcVBd9cg));
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__9a7LZzxhxaoaVRy8OcVBd9cg));
	result.a = a;
	result.b = b;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___59bygf5b7AsTVb9a1lVM66oA)(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q a, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q b) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = (a.line == b.line);
	if (!(T1_)) goto LA2_;
	T1_ = (a.fileIndex == b.fileIndex);
	LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__i80o3k0SgEI5gTRCzYdyWAsystem)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__i80o3k0SgEI5gTRCzYdyWAsystem(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, concat__9brDhFFC9aYh4TjJmoPfzOdw)(NimStringDesc** strings, NI stringsLen_0) {
	NimStringDesc* result;
	NI totalLen;
	result = (NimStringDesc*)0;
	totalLen = ((NI) 0);
	{
		NimStringDesc** s;
		NI i;
		s = (NimStringDesc**)0;
		i = ((NI) 0);
		{
			while (1) {
				if (!(i < stringsLen_0)) goto LA3;
				s = (&strings[i]);
				totalLen += ((*s) ? (*s)->Sup.len : 0);
				i += ((NI) 1);
			} LA3: ;
		}
	}
	result = rawNewString(((NI) (totalLen)));
	{
		NimStringDesc** s_2;
		NI i_2;
		s_2 = (NimStringDesc**)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < stringsLen_0)) goto LA6;
				s_2 = (&strings[i_2]);
				result = resizeString(result, ((*s_2) ? (*s_2)->Sup.len : 0) + 0);
appendString(result, (*s_2));
				i_2 += ((NI) 1);
			} LA6: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toFullPath__VW1RaR1l9c9bPnJxr1KuvIrg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NI32 fileIdx) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (fileIdx < ((NI32) 0));
		if (T3_) goto LA4_;
		T3_ = (conf == ((tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw*) NIM_NIL));
		LA4_: ;
		if (!T3_) goto LA5_;
		{
			if (!(fileIdx == ((NI32) -3))) goto LA9_;
			result = copyString(((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_6));
		}
		goto LA7_;
		LA9_: ;
		{
			result = copyString(((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_7));
		}
		LA7_: ;
	}
	goto LA1_;
	LA5_: ;
	{
		result = copyString((*conf).m.fileInfos->data[fileIdx].fullPath);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toProjPath__VW1RaR1l9c9bPnJxr1KuvIrg_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NI32 fileIdx) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (fileIdx < ((NI32) 0));
		if (T3_) goto LA4_;
		T3_ = (conf == ((tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw*) NIM_NIL));
		LA4_: ;
		if (!T3_) goto LA5_;
		{
			if (!(fileIdx == ((NI32) -3))) goto LA9_;
			result = copyString(((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_6));
		}
		goto LA7_;
		LA9_: ;
		{
			result = copyString(((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_7));
		}
		LA7_: ;
	}
	goto LA1_;
	LA5_: ;
	{
		result = copyString((*conf).m.fileInfos->data[fileIdx].projPath);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toFilenameOption__hCtp6lwFVPBOAIlYyXBiuA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NI32 fileIdx, tyEnum_FilenameOption__PR85MOw9bZL5JFJQSb26org opt) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	switch (opt) {
	case ((tyEnum_FilenameOption__PR85MOw9bZL5JFJQSb26org) 0):
	{
		result = toFullPath__VW1RaR1l9c9bPnJxr1KuvIrg(conf, fileIdx);
	}
	break;
	case ((tyEnum_FilenameOption__PR85MOw9bZL5JFJQSb26org) 1):
	{
		result = toProjPath__VW1RaR1l9c9bPnJxr1KuvIrg_2(conf, fileIdx);
	}
	break;
	case ((tyEnum_FilenameOption__PR85MOw9bZL5JFJQSb26org) 2):
	{
		NimStringDesc* absPath;
		NimStringDesc* relPath;
		absPath = toFullPath__VW1RaR1l9c9bPnJxr1KuvIrg(conf, fileIdx);
		relPath = toProjPath__VW1RaR1l9c9bPnJxr1KuvIrg_2(conf, fileIdx);
		{
			NIM_BOOL T6_;
			NIM_BOOL T7_;
			NI T10_;
			T6_ = (NIM_BOOL)0;
			T7_ = (NIM_BOOL)0;
			T7_ = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 36))&63U)))!=0);
			if (T7_) goto LA8_;
			T7_ = ((absPath ? absPath->Sup.len : 0) < (relPath ? relPath->Sup.len : 0));
			LA8_: ;
			T6_ = T7_;
			if (T6_) goto LA9_;
			T10_ = (NI)0;
			T10_ = nsuCountString(relPath, ((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_8), NIM_FALSE);
			T6_ = (((NI) 2) < T10_);
			LA9_: ;
			if (!T6_) goto LA11_;
			result = copyString(absPath);
		}
		goto LA4_;
		LA11_: ;
		{
			result = copyString(relPath);
		}
		LA4_: ;
	}
	break;
	case ((tyEnum_FilenameOption__PR85MOw9bZL5JFJQSb26org) 3):
	{
		NimStringDesc* T15_;
		T15_ = (NimStringDesc*)0;
		T15_ = toProjPath__VW1RaR1l9c9bPnJxr1KuvIrg_2(conf, fileIdx);
		result = noslastPathPart(T15_);
	}
	break;
	case ((tyEnum_FilenameOption__PR85MOw9bZL5JFJQSb26org) 4):
	{
		{
			if (!(((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 31))&63U)))!=0)) goto LA19_;
			result = toFilenameOption__hCtp6lwFVPBOAIlYyXBiuA(conf, fileIdx, ((tyEnum_FilenameOption__PR85MOw9bZL5JFJQSb26org) 0));
		}
		goto LA17_;
		LA19_: ;
		{
			result = toFilenameOption__hCtp6lwFVPBOAIlYyXBiuA(conf, fileIdx, ((tyEnum_FilenameOption__PR85MOw9bZL5JFJQSb26org) 3));
		}
		LA17_: ;
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toMsgFilename__eX9aCxa5NfPq9alDDS1zYbvw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NI32 info) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	result = toFilenameOption__hCtp6lwFVPBOAIlYyXBiuA(conf, info, ((tyEnum_FilenameOption__PR85MOw9bZL5JFJQSb26org) 2));
	return result;
}
static N_INLINE(NimStringDesc*, toFileLineCol__WM0LdwjY884aJ9cup7BS2vwmsgs)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	NimStringDesc* result;
	NimStringDesc* T1_;
	result = (NimStringDesc*)0;
	T1_ = (NimStringDesc*)0;
	T1_ = toMsgFilename__eX9aCxa5NfPq9alDDS1zYbvw(conf, info.fileIndex);
	result = resizeString(result, (T1_ ? T1_->Sup.len : 0) + 0);
appendString(result, T1_);
	{
		if (!(((NI) 0) < ((NI) (info.line)))) goto LA4_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_9));
		addInt__mftMOxbyu0h4yByfs3sqjA((&result), ((NI64) (((NI) (info.line)))));
		{
			if (!(((NI) 0) < (NI)(((NI) (info.col)) + ((NI) 1)))) goto LA8_;
			result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_10));
			addInt__mftMOxbyu0h4yByfs3sqjA((&result), ((NI64) ((NI)(((NI) (info.col)) + ((NI) 1)))));
		}
		LA8_: ;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_11));
	}
	LA4_: ;
	return result;
}
static N_INLINE(void, writeLine__45Em82MGXqv9biomV0DEbSgio)(FILE* f, NimStringDesc** x, NI xLen_0) {
	{
		NimStringDesc** i;
		NI i_2;
		i = (NimStringDesc**)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < xLen_0)) goto LA3;
				i = (&x[i_2]);
				write__PArlm09bKklm2BLsCg6YtaA(f, (*i));
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	write__PArlm09bKklm2BLsCg6YtaA(f, ((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_14));
}
N_LIB_PRIVATE N_NIMCALL(void, writeContext__qseR1pyA8fYS6Wwflt2zAQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastinfo) {
	tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
	info = lastinfo;
	{
		NI i;
		NI colontmp_;
		NI T2_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T2_ = ((*conf).m.msgContext ? (*conf).m.msgContext->Sup.len : 0);
		colontmp_ = T2_;
		i_2 = ((NI) 0);
		{
			while (1) {
				tyTuple__z822nu9bFF1AlQnLrHjdwpA context;
				if (!(i_2 < colontmp_)) goto LA4;
				i = i_2;
				nimZeroMem((void*)(&context), sizeof(tyTuple__z822nu9bFF1AlQnLrHjdwpA));
				context.Field0 = (*conf).m.msgContext->data[i].Field0;
				context.Field1 = (*conf).m.msgContext->data[i].Field1;
				{
					NIM_BOOL T7_;
					NIM_BOOL T8_;
					NIM_BOOL T10_;
					T7_ = (NIM_BOOL)0;
					T8_ = (NIM_BOOL)0;
					T8_ = eqeq___59bygf5b7AsTVb9a1lVM66oA(context.Field0, lastinfo);
					T7_ = !(T8_);
					if (!(T7_)) goto LA9_;
					T10_ = (NIM_BOOL)0;
					T10_ = eqeq___59bygf5b7AsTVb9a1lVM66oA(context.Field0, info);
					T7_ = !(T10_);
					LA9_: ;
					if (!T7_) goto LA11_;
					{
						if (!!(((*conf).structuredErrorHook.ClP_0 == TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_2.ClP_0 && (*conf).structuredErrorHook.ClE_0 == TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_2.ClE_0))) goto LA15_;
						(*conf).structuredErrorHook.ClE_0? (*conf).structuredErrorHook.ClP_0(conf, context.Field0, ((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_3), ((tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA) 0), (*conf).structuredErrorHook.ClE_0):((TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_4)((*conf).structuredErrorHook.ClP_0))(conf, context.Field0, ((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_3), ((tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA) 0));
					}
					goto LA13_;
					LA15_: ;
					{
						NimStringDesc* message;
						{
							if (!((context.Field1 ? context.Field1->Sup.len : 0) == 0)) goto LA20_;
							message = copyString(((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_3));
						}
						goto LA18_;
						LA20_: ;
						{
							tyArray__nHXaesL0DJZHyVS07ARPRA T23_;
							nimZeroMem((void*)T23_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
							T23_[0] = copyString(context.Field1);
							message = nsuFormatVarargs(((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_5), T23_, 1);
						}
						LA18_: ;
						{
							tyArray__24KAM9afIUgUaqBaEBB6r9bg T28_;
							NimStringDesc* T29_;
							if (!!(((*conf).writelnHook.ClP_0 == 0))) goto LA26_;
							nimZeroMem((void*)T28_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
							T28_[0] = toFileLineCol__WM0LdwjY884aJ9cup7BS2vwmsgs(conf, context.Field0);
							T28_[1] = copyString(((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_12));
							T28_[2] = copyString(message);
							T29_ = (NimStringDesc*)0;
							T29_ = concat__9brDhFFC9aYh4TjJmoPfzOdw(T28_, 3);
							(*conf).writelnHook.ClE_0? (*conf).writelnHook.ClP_0(T29_, (*conf).writelnHook.ClE_0):((TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_13)((*conf).writelnHook.ClP_0))(T29_);
						}
						goto LA24_;
						LA26_: ;
						{
							if (!(((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 23))&63U)))!=0)) goto LA31_;
							{
								tyArray__24KAM9afIUgUaqBaEBB6r9bg T41_;
								if (!(((*conf).m.errorOutputs &((NU8)1<<((NU)(((tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA) 0))&7U)))!=0)) goto LA35_;
								{
									if (!(*conf).lastMsgWasDot) goto LA39_;
									(*conf).lastMsgWasDot = NIM_FALSE;
									write__PArlm09bKklm2BLsCg6YtaA(__stdoutp, ((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_14));
								}
								LA39_: ;
								nimZeroMem((void*)T41_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
								T41_[0] = toFileLineCol__WM0LdwjY884aJ9cup7BS2vwmsgs(conf, context.Field0);
								T41_[1] = copyString(((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_12));
								T41_[2] = copyString(message);
								writeLine__45Em82MGXqv9biomV0DEbSgio(__stdoutp, T41_, 3);
								flushFile__fU6ZlJAtQ9bre04EDZLdGsA_2(__stdoutp);
							}
							LA35_: ;
						}
						goto LA24_;
						LA31_: ;
						{
							if (!(((*conf).m.errorOutputs &((NU8)1<<((NU)(((tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA) 1))&7U)))!=0)) goto LA43_;
							{
								if (!(*conf).lastMsgWasDot) goto LA47_;
								(*conf).lastMsgWasDot = NIM_FALSE;
								write__PArlm09bKklm2BLsCg6YtaA(__stderrp, ((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_14));
							}
							LA47_: ;
							{
								NimStringDesc* T53_;
								if (!(((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 21))&63U)))!=0)) goto LA51_;
								setStyle__y8lW2LrW2n5ZHaxH9bAf4WA(__stderrp, 1);
								T53_ = (NimStringDesc*)0;
								T53_ = toFileLineCol__WM0LdwjY884aJ9cup7BS2vwmsgs(conf, context.Field0);
								write__PArlm09bKklm2BLsCg6YtaA(__stderrp, T53_);
								write__PArlm09bKklm2BLsCg6YtaA(__stderrp, ((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_12));
								resetAttributes__6J8xlU57R8cS9bLzTS89aM5g(__stderrp);
								write__PArlm09bKklm2BLsCg6YtaA(__stderrp, message);
								resetAttributes__6J8xlU57R8cS9bLzTS89aM5g(__stderrp);
								write__PArlm09bKklm2BLsCg6YtaA(__stderrp, ((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_14));
							}
							goto LA49_;
							LA51_: ;
							{
								tyArray__24KAM9afIUgUaqBaEBB6r9bg T55_;
								nimZeroMem((void*)T55_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
								T55_[0] = toFileLineCol__WM0LdwjY884aJ9cup7BS2vwmsgs(conf, context.Field0);
								T55_[1] = copyString(((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_12));
								T55_[2] = copyString(message);
								writeLine__45Em82MGXqv9biomV0DEbSgio(__stderrp, T55_, 3);
							}
							LA49_: ;
						}
						goto LA24_;
						LA43_: ;
						LA24_: ;
					}
					LA13_: ;
				}
				LA11_: ;
				info = context.Field0;
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, msgKindToString__pY9bbQrdTPzM2HGfayOe6eQ)(tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w kind) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	result = copyString(MsgKindToStr__toc2ERobyllo49aZhx0umtQ[(kind)- 0]);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getMessageStr__bApVJwLsexHv26MjGbKUvQ)(tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w msg, NimStringDesc* arg) {
	NimStringDesc* result;
	NimStringDesc* T1_;
	tyArray__nHXaesL0DJZHyVS07ARPRA T2_;
	result = (NimStringDesc*)0;
	T1_ = (NimStringDesc*)0;
	T1_ = msgKindToString__pY9bbQrdTPzM2HGfayOe6eQ(msg);
	nimZeroMem((void*)T2_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
	T2_[0] = copyString(arg);
	result = nsuFormatOpenArray(T1_, T2_, 1);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, ignoreMsgBecauseOfIdeTools__wvc4V6zIgESu6cpPmGz9abA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w msg) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = (((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10) <= msg);
	if (!(T2_)) goto LA3_;
	T2_ = ((*conf).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 14));
	LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T1_ = !((((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 29))&63U)))!=0));
	LA4_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, msgWrite__NefEsy9c5k5U9cqqVIWMbpKg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* s) {
	{
		FILE* stdOrr;
		if (!!(((*conf).m.errorOutputs == 0))) goto LA3_;
		{
			if (!(((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 23))&63U)))!=0)) goto LA7_;
			stdOrr = __stdoutp;
		}
		goto LA5_;
		LA7_: ;
		{
			stdOrr = __stderrp;
		}
		LA5_: ;
		write__PArlm09bKklm2BLsCg6YtaA(stdOrr, s);
		flushFile__fU6ZlJAtQ9bre04EDZLdGsA_2(stdOrr);
		(*conf).lastMsgWasDot = NIM_TRUE;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, msgWriteln__PO49anyWCbe63GYNOs9cVuvg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* s, tySet_tyEnum_MsgFlag__BzRTaQ6LrPDZKEKt9bswkOQ flags) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*conf).writelnHook.ClP_0 == 0));
		if (!(T3_)) goto LA4_;
		T3_ = !(((flags &((NU8)1<<((NU)(((tyEnum_MsgFlag__BzRTaQ6LrPDZKEKt9bswkOQ) 1))&7U)))!=0));
		LA4_: ;
		if (!T3_) goto LA5_;
		(*conf).writelnHook.ClE_0? (*conf).writelnHook.ClP_0(s, (*conf).writelnHook.ClE_0):((TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_22)((*conf).writelnHook.ClP_0))(s);
	}
	goto LA1_;
	LA5_: ;
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 23))&63U)))!=0);
		if (T8_) goto LA9_;
		T8_ = ((flags &((NU8)1<<((NU)(((tyEnum_MsgFlag__BzRTaQ6LrPDZKEKt9bswkOQ) 0))&7U)))!=0);
		LA9_: ;
		if (!T8_) goto LA10_;
		{
			tyArray__nHXaesL0DJZHyVS07ARPRA T20_;
			if (!(((*conf).m.errorOutputs &((NU8)1<<((NU)(((tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA) 0))&7U)))!=0)) goto LA14_;
			{
				if (!(*conf).lastMsgWasDot) goto LA18_;
				(*conf).lastMsgWasDot = NIM_FALSE;
				write__PArlm09bKklm2BLsCg6YtaA(__stdoutp, ((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_14));
			}
			LA18_: ;
			nimZeroMem((void*)T20_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
			T20_[0] = copyString(s);
			writeLine__45Em82MGXqv9biomV0DEbSgio(__stdoutp, T20_, 1);
			flushFile__fU6ZlJAtQ9bre04EDZLdGsA_2(__stdoutp);
		}
		LA14_: ;
	}
	goto LA1_;
	LA10_: ;
	{
		{
			tyArray__nHXaesL0DJZHyVS07ARPRA T30_;
			if (!(((*conf).m.errorOutputs &((NU8)1<<((NU)(((tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA) 1))&7U)))!=0)) goto LA24_;
			{
				if (!(*conf).lastMsgWasDot) goto LA28_;
				(*conf).lastMsgWasDot = NIM_FALSE;
				write__PArlm09bKklm2BLsCg6YtaA(__stderrp, ((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_14));
			}
			LA28_: ;
			nimZeroMem((void*)T30_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
			T30_[0] = copyString(s);
			writeLine__45Em82MGXqv9biomV0DEbSgio(__stderrp, T30_, 1);
		}
		LA24_: ;
	}
	LA1_: ;
}
static N_INLINE(void, pushSafePoint)(TSafePoint* s) {
	(*s).prev = excHandler__rqLlY5bs9atDw2OXYqJEn5g;
	excHandler__rqLlY5bs9atDw2OXYqJEn5g = s;
}
static N_INLINE(NIM_BOOL, isEmpty__kPpSxL0H5sJ9a6ujvdQ0QVQpathutils)(NimStringDesc* x) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((x ? x->Sup.len : 0) == ((NI) 0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toFullPathConsiderDirty__fr10i3QiqDDNG5EqWBCesA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NI32 fileIdx) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	{
		if (!(fileIdx < ((NI32) 0))) goto LA3_;
		{
			if (!(fileIdx == ((NI32) -3))) goto LA7_;
			result = copyString(((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_6));
		}
		goto LA5_;
		LA7_: ;
		{
			result = copyString(((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_7));
		}
		LA5_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T11_;
		T11_ = (NIM_BOOL)0;
		T11_ = isEmpty__kPpSxL0H5sJ9a6ujvdQ0QVQpathutils((*conf).m.fileInfos->data[fileIdx].dirtyFile);
		if (!!(T11_)) goto LA12_;
		result = copyString((*conf).m.fileInfos->data[fileIdx].dirtyFile);
	}
	goto LA1_;
	LA12_: ;
	{
		result = copyString((*conf).m.fileInfos->data[fileIdx].fullPath);
	}
	LA1_: ;
	return result;
}
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) + (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* result;
	NI T1_;
	result = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	addZCT__Y66tOYFjgwJ0k4aLz4bc0Q((&gch__IcYaEuuWivYAS86vFMTS3Q.zct), c);
}
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T5_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(src);
		incRef__AT1eRuflKWyTTBdLjEDZbg_3system(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T10_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem((*dest));
		decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T1_;
	T1_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(p);
	decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T1_);
}
N_LIB_PRIVATE N_NIMCALL(void, addSourceLine__9cPswkSBuJ0YLnDEBw6Iieg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NI32 fileIdx, NimStringDesc* line) {
	NI T1_;
	NimStringDesc* T2_;
	asgnRef((void**) (&(*conf).m.fileInfos->data[fileIdx].lines), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*conf).m.fileInfos->data[fileIdx].lines), (&NTI__sM4lkSb7zS6F7OVMvW9cffQ_)));
	T1_ = (*conf).m.fileInfos->data[fileIdx].lines->Sup.len++;
	T2_ = (NimStringDesc*)0;
	T2_ = (*conf).m.fileInfos->data[fileIdx].lines->data[T1_]; (*conf).m.fileInfos->data[fileIdx].lines->data[T1_] = copyStringRC1(line);
	if (T2_) nimGCunrefNoCycle(T2_);
}
static N_INLINE(void, popSafePoint)(void) {
	excHandler__rqLlY5bs9atDw2OXYqJEn5g = (*excHandler__rqLlY5bs9atDw2OXYqJEn5g).prev;
}
static N_INLINE(Exception*, nimBorrowCurrentException)(void) {
	Exception* result;
	result = (Exception*)0;
	result = currException__9bVPeDJlYTi9bQApZpfH8wjg;
	return result;
}
static N_INLINE(void, popCurrentException)(void) {
	asgnRef((void**) (&currException__9bVPeDJlYTi9bQApZpfH8wjg), (*currException__9bVPeDJlYTi9bQApZpfH8wjg).up);
}
N_LIB_PRIVATE N_NIMCALL(NI, numLines__x9aqxDAtGd57HztdSIhXLtQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NI32 fileIdx) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*conf).m.fileInfos->data[fileIdx].lines ? (*conf).m.fileInfos->data[fileIdx].lines->Sup.len : 0);
	result = T1_;
	{
		TSafePoint TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_24;
		NI T14_;
		if (!(result == ((NI) 0))) goto LA4_;
		pushSafePoint(&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_24);
		TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_24.status = _setjmp(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_24.context);
		if (TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_24.status == 0) {
		{
			NimStringDesc* line;
			NimStringDesc* colontmp_;
			FILE* f;
			TSafePoint TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_25;
			NimStringDesc* res;
			line = (NimStringDesc*)0;
			colontmp_ = (NimStringDesc*)0;
			colontmp_ = toFullPathConsiderDirty__fr10i3QiqDDNG5EqWBCesA(conf, fileIdx);
			f = open__cb1k9citqyT9a9brBSJAz8pkg(colontmp_, ((tyEnum_FileMode__ZJfK20XeZ9bv2j1pZjw9aswg) 0), ((NI) 8000));
			pushSafePoint(&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_25);
			TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_25.status = _setjmp(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_25.context);
			if (TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_25.status == 0) {
			res = rawNewString(((NI) 80));
			{
				while (1) {
					NIM_BOOL T9_;
					T9_ = (NIM_BOOL)0;
					T9_ = readLine__FbqDHP9bu7nqCh9c04dnSOxw(f, (&res));
					if (!T9_) goto LA8;
					line = res;
					addSourceLine__9cPswkSBuJ0YLnDEBw6Iieg(conf, fileIdx, line);
				} LA8: ;
			}
			popSafePoint();
			}
			else {
				popSafePoint();
			}
			{
				close__fU6ZlJAtQ9bre04EDZLdGsA_3(f);
				if (TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_25.status != 0) nimLeaveFinally();
			}
			if (TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_25.status != 0) reraiseException();
		}
		popSafePoint();
		}
		else {
			popSafePoint();
			if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTI__iLZrPn9anoh9ad1MmO0RczFw_))) {
				TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_24.status = 0;
				popCurrentException();
			}
		}
		if (TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_24.status != 0) reraiseException();
		T14_ = ((*conf).m.fileInfos->data[fileIdx].lines ? (*conf).m.fileInfos->data[fileIdx].lines->Sup.len : 0);
		result = T14_;
	}
	LA4_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, sourceLine__b49bYNvmBdG6RP9cHaZGFhvQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q i) {
	NimStringDesc* result;
	NI num;
{	result = (NimStringDesc*)0;
	{
		if (!(i.fileIndex < ((NI32) 0))) goto LA3_;
		result = ((NimStringDesc*) NIM_NIL);
		goto BeforeRet_;
	}
	LA3_: ;
	num = numLines__x9aqxDAtGd57HztdSIhXLtQ(conf, i.fileIndex);
	{
		if (!(num < ((NI) (i.line)))) goto LA7_;
		result = ((NimStringDesc*) NIM_NIL);
		goto BeforeRet_;
	}
	LA7_: ;
	result = copyString((*conf).m.fileInfos->data[i.fileIndex].lines->data[(NI)(((NI) (i.line)) - ((NI) 1))]);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NimStringDesc*, spaces__rssDy7zs9cDeoYTeCoIy0Wgstrutils)(NI n) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	result = nsuRepeatChar(32, n);
	return result;
}
static N_INLINE(void, appendChar)(NimStringDesc* dest, NIM_CHAR c) {
	(*dest).data[(*dest).Sup.len] = c;
	(*dest).data[(NI)((*dest).Sup.len + ((NI) 1))] = 0;
	(*dest).Sup.len += ((NI) 1);
}
N_LIB_PRIVATE N_NIMCALL(void, writeSurroundingSrc__9aRUSlnze6Qb3IwHkkQ9bv6g)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	T1_ = (NimStringDesc*)0;
	T2_ = (NimStringDesc*)0;
	T2_ = sourceLine__b49bYNvmBdG6RP9cHaZGFhvQ(conf, info);
	T1_ = rawNewString((T2_ ? T2_->Sup.len : 0) + 2);
appendString(T1_, ((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_23));
appendString(T1_, T2_);
	msgWriteln__PO49anyWCbe63GYNOs9cVuvg(conf, T1_, 0);
	{
		NimStringDesc* T7_;
		NimStringDesc* T8_;
		if (!(((NI16) 0) <= info.col)) goto LA5_;
		T7_ = (NimStringDesc*)0;
		T8_ = (NimStringDesc*)0;
		T8_ = spaces__rssDy7zs9cDeoYTeCoIy0Wgstrutils(((NI) (info.col)));
		T7_ = rawNewString((T8_ ? T8_->Sup.len : 0) + 3);
appendString(T7_, ((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_23));
appendString(T7_, T8_);
appendChar(T7_, 94);
		msgWriteln__PO49anyWCbe63GYNOs9cVuvg(conf, T7_, 0);
	}
	LA5_: ;
}
static N_INLINE(NimStringDesc*, toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	result = resizeString(result, (info.Field0 ? info.Field0->Sup.len : 0) + 0);
appendString(result, info.Field0);
	{
		if (!(((NI) 0) < info.Field1)) goto LA3_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_9));
		addInt__mftMOxbyu0h4yByfs3sqjA((&result), ((NI64) (info.Field1)));
		{
			if (!(((NI) 0) < (NI)(info.Field2 + ((NI) 1)))) goto LA7_;
			result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_10));
			addInt__mftMOxbyu0h4yByfs3sqjA((&result), ((NI64) ((NI)(info.Field2 + ((NI) 1)))));
		}
		LA7_: ;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_11));
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, log__tRbCZ4fGDe9a36bXIedwnwQ)(NimStringDesc* s) {
	FILE* f;
	f = (FILE*)0;
	{
		NimStringDesc* T3_;
		NimStringDesc* T4_;
		NIM_BOOL T5_;
		tyArray__nHXaesL0DJZHyVS07ARPRA T8_;
		T3_ = (NimStringDesc*)0;
		T3_ = nosgetHomeDir();
		T4_ = (NimStringDesc*)0;
		T4_ = slash___gEyhbzZ1UcxyenWRLJRXNQ(T3_, ((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_29));
		T5_ = (NIM_BOOL)0;
		T5_ = open__gq12VLhVO0NBzUTnGgz4nw(&f, T4_, ((tyEnum_FileMode__ZJfK20XeZ9bv2j1pZjw9aswg) 4), ((NI) -1));
		if (!T5_) goto LA6_;
		nimZeroMem((void*)T8_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
		T8_[0] = copyString(s);
		writeLine__45Em82MGXqv9biomV0DEbSgio(f, T8_, 1);
		close__fU6ZlJAtQ9bre04EDZLdGsA_3(f);
	}
	LA6_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, quit__Fedq6hIgzK5Ezo80jU9aqAg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w msg) {
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = NIM_FALSE;
		if (T4_) goto LA5_;
		T4_ = (msg == ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 1));
		LA5_: ;
		T3_ = T4_;
		if (T3_) goto LA6_;
		T3_ = hasHint__zh6OC34d9cPUHXjZ4qVA9bkw_2(conf, ((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) 76));
		LA6_: ;
		if (!T3_) goto LA7_;
		{
			NIM_BOOL T11_;
			T11_ = (NIM_BOOL)0;
			T11_ = stackTraceAvailable__xiAaEKYdoaDLIIbJ78BqmQ();
			if (!(T11_)) goto LA12_;
			T11_ = ((*conf).writelnHook.ClP_0 == 0);
			LA12_: ;
			if (!T11_) goto LA13_;
			writeStackTrace__amVlU9ajqZ06ujoesRBHcDg_4();
		}
		goto LA9_;
		LA13_: ;
		{
			{
				tyArray__nHXaesL0DJZHyVS07ARPRA T20_;
				tyArray__Re75IspeoxXy2oCZHwcRrA T21_;
				NimStringDesc* T22_;
				if (!!(((*conf).writelnHook.ClP_0 == 0))) goto LA18_;
				nimZeroMem((void*)T20_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
				nimZeroMem((void*)T21_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
				T21_[0] = copyString((*conf).command);
				T21_[1] = createDocLink__pWiLD3R2s41obcTDlPhj9cA(((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_31));
				T20_[0] = nsuFormatOpenArray(((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_30), T21_, 2);
				T22_ = (NimStringDesc*)0;
				T22_ = concat__9brDhFFC9aYh4TjJmoPfzOdw(T20_, 1);
				(*conf).writelnHook.ClE_0? (*conf).writelnHook.ClP_0(T22_, (*conf).writelnHook.ClE_0):((TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_32)((*conf).writelnHook.ClP_0))(T22_);
			}
			goto LA16_;
			LA18_: ;
			{
				if (!(((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 23))&63U)))!=0)) goto LA24_;
				{
					tyArray__nHXaesL0DJZHyVS07ARPRA T34_;
					tyArray__Re75IspeoxXy2oCZHwcRrA T35_;
					if (!(((*conf).m.errorOutputs &((NU8)1<<((NU)(((tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA) 0))&7U)))!=0)) goto LA28_;
					{
						if (!(*conf).lastMsgWasDot) goto LA32_;
						(*conf).lastMsgWasDot = NIM_FALSE;
						write__PArlm09bKklm2BLsCg6YtaA(__stdoutp, ((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_14));
					}
					LA32_: ;
					nimZeroMem((void*)T34_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
					nimZeroMem((void*)T35_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
					T35_[0] = copyString((*conf).command);
					T35_[1] = createDocLink__pWiLD3R2s41obcTDlPhj9cA(((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_31));
					T34_[0] = nsuFormatOpenArray(((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_30), T35_, 2);
					writeLine__45Em82MGXqv9biomV0DEbSgio(__stdoutp, T34_, 1);
					flushFile__fU6ZlJAtQ9bre04EDZLdGsA_2(__stdoutp);
				}
				LA28_: ;
			}
			goto LA16_;
			LA24_: ;
			{
				if (!(((*conf).m.errorOutputs &((NU8)1<<((NU)(((tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA) 1))&7U)))!=0)) goto LA37_;
				{
					if (!(*conf).lastMsgWasDot) goto LA41_;
					(*conf).lastMsgWasDot = NIM_FALSE;
					write__PArlm09bKklm2BLsCg6YtaA(__stderrp, ((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_14));
				}
				LA41_: ;
				{
					tyArray__Re75IspeoxXy2oCZHwcRrA T47_;
					NimStringDesc* T48_;
					if (!(((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 21))&63U)))!=0)) goto LA45_;
					setForegroundColor__vJutklhcnQq9akCXxcuSHAg(__stderrp, ((tyEnum_ForegroundColor__ez9ah4IgQc0AbdW68acioDg) 31), NIM_FALSE);
					nimZeroMem((void*)T47_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
					T47_[0] = copyString((*conf).command);
					T47_[1] = createDocLink__pWiLD3R2s41obcTDlPhj9cA(((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_31));
					T48_ = (NimStringDesc*)0;
					T48_ = nsuFormatOpenArray(((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_30), T47_, 2);
					write__PArlm09bKklm2BLsCg6YtaA(__stderrp, T48_);
					resetAttributes__6J8xlU57R8cS9bLzTS89aM5g(__stderrp);
					write__PArlm09bKklm2BLsCg6YtaA(__stderrp, ((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_14));
				}
				goto LA43_;
				LA45_: ;
				{
					tyArray__nHXaesL0DJZHyVS07ARPRA T50_;
					tyArray__Re75IspeoxXy2oCZHwcRrA T51_;
					nimZeroMem((void*)T50_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
					nimZeroMem((void*)T51_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
					T51_[0] = copyString((*conf).command);
					T51_[1] = createDocLink__pWiLD3R2s41obcTDlPhj9cA(((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_31));
					T50_[0] = nsuFormatOpenArray(((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_30), T51_, 2);
					writeLine__45Em82MGXqv9biomV0DEbSgio(__stderrp, T50_, 1);
				}
				LA43_: ;
			}
			goto LA16_;
			LA37_: ;
			LA16_: ;
		}
		LA9_: ;
	}
	LA7_: ;
	exit(((NI) 1));
}
N_LIB_PRIVATE N_NIMCALL(void, handleError__T2cS0vBHloueESngIcrNPg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w msg, tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw eh, NimStringDesc* s) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 0) <= msg);
		if (!(T3_)) goto LA4_;
		T3_ = (msg <= ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 1));
		LA4_: ;
		if (!T3_) goto LA5_;
		{
			if (!((*conf).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 14))) goto LA9_;
			log__tRbCZ4fGDe9a36bXIedwnwQ(s);
		}
		LA9_: ;
		quit__Fedq6hIgzK5Ezo80jU9aqAg(conf, msg);
	}
	LA5_: ;
	{
		NIM_BOOL T13_;
		NIM_BOOL T14_;
		NIM_BOOL T17_;
		tyObject_HSlice__9a7LZzxhxaoaVRy8OcVBd9cg T18_;
		T13_ = (NIM_BOOL)0;
		T14_ = (NIM_BOOL)0;
		T14_ = (((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 0) <= msg);
		if (!(T14_)) goto LA15_;
		T14_ = (msg <= ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 11));
		LA15_: ;
		T13_ = T14_;
		if (T13_) goto LA16_;
		T17_ = (NIM_BOOL)0;
		T18_ = dotdot___N3IU9cJ5UjABfbcVFvMuhrQsystem(((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 12), ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 51));
		T17_ = contains__C6zknI9aj0qzb4XAbwM6y9cQsystem(T18_, msg);
		if (!(T17_)) goto LA19_;
		T17_ = (((*conf).warningAsErrors[(NU)((((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) (msg))- 12))>>3] &(1U<<((NU)((((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) (msg))- 12))&7U)))!=0);
		LA19_: ;
		T13_ = T17_;
		LA16_: ;
		if (!T13_) goto LA20_;
		(*conf).errorCounter += ((NI) 1);
		(*conf).exitcode = ((NI8) 1);
		{
			if (!((*conf).errorMax <= (*conf).errorCounter)) goto LA24_;
			quit__Fedq6hIgzK5Ezo80jU9aqAg(conf, msg);
		}
		goto LA22_;
		LA24_: ;
		{
			NIM_BOOL T27_;
			T27_ = (NIM_BOOL)0;
			T27_ = (eh == ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 1));
			if (!(T27_)) goto LA28_;
			T27_ = !(((*conf).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 14)));
			LA28_: ;
			if (!T27_) goto LA29_;
			quit__Fedq6hIgzK5Ezo80jU9aqAg(conf, msg);
		}
		goto LA22_;
		LA29_: ;
		{
			if (!(eh == ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 2))) goto LA32_;
			raiseRecoverableError__5jd5IdwI3N06CaI2zjEQsQ(s);
		}
		goto LA22_;
		LA32_: ;
		LA22_: ;
	}
	LA20_: ;
}
N_LIB_PRIVATE N_NOINLINE(void, liMessage__Q6JNH4uRwLyZrj0dJakHew)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w msg, NimStringDesc* arg, tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw) {
	NimStringDesc* title;
	tyEnum_ForegroundColor__ez9ah4IgQc0AbdW68acioDg color;
	NIM_BOOL ignoreMsg;
	tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA sev;
	NimStringDesc* kind;
	NimStringDesc* s;
	title = (NimStringDesc*)0;
	color = (tyEnum_ForegroundColor__ez9ah4IgQc0AbdW68acioDg)0;
	ignoreMsg = NIM_FALSE;
	sev = (tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA)0;
	{
		NIM_BOOL T3_;
		tyObject_HSlice__9a7LZzxhxaoaVRy8OcVBd9cg T4_;
		T3_ = (NIM_BOOL)0;
		T4_ = dotdot___N3IU9cJ5UjABfbcVFvMuhrQsystem(((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 12), ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 83));
		T3_ = contains__C6zknI9aj0qzb4XAbwM6y9cQsystem(T4_, msg);
		if (!(T3_)) goto LA5_;
		T3_ = !((msg == ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 81)));
		LA5_: ;
		if (!T3_) goto LA6_;
		kind = reprEnum((NI)msg, (&NTI__29cbg2fC1z5iM1PAI28kR5w_));
	}
	goto LA1_;
	LA6_: ;
	{
		kind = ((NimStringDesc*) NIM_NIL);
	}
	LA1_: ;
	switch (msg) {
	case ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 0) ... ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 11):
	{
		sev = ((tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA) 2);
		writeContext__qseR1pyA8fYS6Wwflt2zAQ(conf, info);
		title = copyString(((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_15));
		color = ((tyEnum_ForegroundColor__ez9ah4IgQc0AbdW68acioDg) 31);
		{
			NIM_BOOL T12_;
			T12_ = (NIM_BOOL)0;
			T12_ = eqeq___59bygf5b7AsTVb9a1lVM66oA(info, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg);
			if (!!(T12_)) goto LA13_;
			(*conf).m.lastError = info;
		}
		LA13_: ;
	}
	break;
	case ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 12) ... ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 51):
	{
		NIM_BOOL T16_;
		sev = ((tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA) 1);
		T16_ = (NIM_BOOL)0;
		T16_ = hasWarn__zh6OC34d9cPUHXjZ4qVA9bkw(conf, ((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) (msg)));
		ignoreMsg = !(T16_);
		{
			if (!(((*conf).warningAsErrors[(NU)((((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) (msg))- 12))>>3] &(1U<<((NU)((((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) (msg))- 12))&7U)))!=0)) goto LA19_;
			ignoreMsg = NIM_FALSE;
			title = copyString(((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_15));
		}
		goto LA17_;
		LA19_: ;
		{
			title = copyString(((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_16));
		}
		LA17_: ;
		{
			if (!!(ignoreMsg)) goto LA24_;
			writeContext__qseR1pyA8fYS6Wwflt2zAQ(conf, info);
		}
		LA24_: ;
		color = ((tyEnum_ForegroundColor__ez9ah4IgQc0AbdW68acioDg) 33);
		(*conf).warnCounter += ((NI) 1);
	}
	break;
	case ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 52) ... ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 83):
	{
		NIM_BOOL T27_;
		sev = ((tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA) 0);
		T27_ = (NIM_BOOL)0;
		T27_ = hasHint__zh6OC34d9cPUHXjZ4qVA9bkw_2(conf, ((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) (msg)));
		ignoreMsg = !(T27_);
		title = copyString(((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_17));
		color = ((tyEnum_ForegroundColor__ez9ah4IgQc0AbdW68acioDg) 32);
		(*conf).hintCounter += ((NI) 1);
	}
	break;
	}
	{
		if (!isRaw) goto LA30_;
		s = arg;
	}
	goto LA28_;
	LA30_: ;
	{
		s = getMessageStr__bApVJwLsexHv26MjGbKUvQ(msg, arg);
	}
	LA28_: ;
	{
		NimStringDesc* loc;
		NimStringDesc* kindmsg;
		if (!!(ignoreMsg)) goto LA35_;
		{
			NIM_BOOL T39_;
			NimStringDesc* T42_;
			NimStringDesc* T43_;
			T39_ = (NIM_BOOL)0;
			T39_ = eqeq___59bygf5b7AsTVb9a1lVM66oA(info, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg);
			if (!!(T39_)) goto LA40_;
			T42_ = (NimStringDesc*)0;
			T43_ = (NimStringDesc*)0;
			T43_ = toFileLineCol__WM0LdwjY884aJ9cup7BS2vwmsgs(conf, info);
			T42_ = rawNewString((T43_ ? T43_->Sup.len : 0) + 1);
appendString(T42_, T43_);
appendString(T42_, ((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_12));
			loc = T42_;
		}
		goto LA37_;
		LA40_: ;
		{
			loc = ((NimStringDesc*) NIM_NIL);
		}
		LA37_: ;
		{
			if (!(((NI) 0) < (kind ? kind->Sup.len : 0))) goto LA47_;
			kindmsg = nsuFormatSingleElem(((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_18), kind);
		}
		goto LA45_;
		LA47_: ;
		{
			kindmsg = ((NimStringDesc*) NIM_NIL);
		}
		LA45_: ;
		{
			NimStringDesc* T54_;
			if (!!(((*conf).structuredErrorHook.ClP_0 == TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_2.ClP_0 && (*conf).structuredErrorHook.ClE_0 == TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_2.ClE_0))) goto LA52_;
			T54_ = (NimStringDesc*)0;
			T54_ = rawNewString((s ? s->Sup.len : 0) + (kindmsg ? kindmsg->Sup.len : 0) + 0);
appendString(T54_, s);
appendString(T54_, kindmsg);
			(*conf).structuredErrorHook.ClE_0? (*conf).structuredErrorHook.ClP_0(conf, info, T54_, sev, (*conf).structuredErrorHook.ClE_0):((TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_19)((*conf).structuredErrorHook.ClP_0))(conf, info, T54_, sev);
		}
		LA52_: ;
		{
			NIM_BOOL T57_;
			T57_ = (NIM_BOOL)0;
			T57_ = ignoreMsgBecauseOfIdeTools__wvc4V6zIgESu6cpPmGz9abA(conf, msg);
			if (!!(T57_)) goto LA58_;
			{
				if (!(msg == ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 62))) goto LA62_;
				msgWrite__NefEsy9c5k5U9cqqVIWMbpKg(conf, ((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_20));
			}
			goto LA60_;
			LA62_: ;
			{
				{
					tyArray__sMpvt1sOxOJ3LFGulnbeMQ T69_;
					NimStringDesc* T70_;
					if (!!(((*conf).writelnHook.ClP_0 == 0))) goto LA67_;
					nimZeroMem((void*)T69_, sizeof(tyArray__sMpvt1sOxOJ3LFGulnbeMQ));
					T69_[0] = copyString(loc);
					T69_[1] = copyString(title);
					T69_[2] = copyString(s);
					T69_[3] = copyString(kindmsg);
					T70_ = (NimStringDesc*)0;
					T70_ = concat__9brDhFFC9aYh4TjJmoPfzOdw(T69_, 4);
					(*conf).writelnHook.ClE_0? (*conf).writelnHook.ClP_0(T70_, (*conf).writelnHook.ClE_0):((TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_21)((*conf).writelnHook.ClP_0))(T70_);
				}
				goto LA65_;
				LA67_: ;
				{
					if (!(((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 23))&63U)))!=0)) goto LA72_;
					{
						tyArray__sMpvt1sOxOJ3LFGulnbeMQ T82_;
						if (!(((*conf).m.errorOutputs &((NU8)1<<((NU)(((tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA) 0))&7U)))!=0)) goto LA76_;
						{
							if (!(*conf).lastMsgWasDot) goto LA80_;
							(*conf).lastMsgWasDot = NIM_FALSE;
							write__PArlm09bKklm2BLsCg6YtaA(__stdoutp, ((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_14));
						}
						LA80_: ;
						nimZeroMem((void*)T82_, sizeof(tyArray__sMpvt1sOxOJ3LFGulnbeMQ));
						T82_[0] = copyString(loc);
						T82_[1] = copyString(title);
						T82_[2] = copyString(s);
						T82_[3] = copyString(kindmsg);
						writeLine__45Em82MGXqv9biomV0DEbSgio(__stdoutp, T82_, 4);
						flushFile__fU6ZlJAtQ9bre04EDZLdGsA_2(__stdoutp);
					}
					LA76_: ;
				}
				goto LA65_;
				LA72_: ;
				{
					if (!(((*conf).m.errorOutputs &((NU8)1<<((NU)(((tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA) 1))&7U)))!=0)) goto LA84_;
					{
						if (!(*conf).lastMsgWasDot) goto LA88_;
						(*conf).lastMsgWasDot = NIM_FALSE;
						write__PArlm09bKklm2BLsCg6YtaA(__stderrp, ((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_14));
					}
					LA88_: ;
					{
						if (!(((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 21))&63U)))!=0)) goto LA92_;
						setStyle__y8lW2LrW2n5ZHaxH9bAf4WA(__stderrp, 1);
						write__PArlm09bKklm2BLsCg6YtaA(__stderrp, loc);
						resetAttributes__6J8xlU57R8cS9bLzTS89aM5g(__stderrp);
						setForegroundColor__vJutklhcnQq9akCXxcuSHAg(__stderrp, color, NIM_FALSE);
						write__PArlm09bKklm2BLsCg6YtaA(__stderrp, title);
						resetAttributes__6J8xlU57R8cS9bLzTS89aM5g(__stderrp);
						write__PArlm09bKklm2BLsCg6YtaA(__stderrp, s);
						setForegroundColor__vJutklhcnQq9akCXxcuSHAg(__stderrp, ((tyEnum_ForegroundColor__ez9ah4IgQc0AbdW68acioDg) 36), NIM_FALSE);
						write__PArlm09bKklm2BLsCg6YtaA(__stderrp, kindmsg);
						resetAttributes__6J8xlU57R8cS9bLzTS89aM5g(__stderrp);
						write__PArlm09bKklm2BLsCg6YtaA(__stderrp, ((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_14));
					}
					goto LA90_;
					LA92_: ;
					{
						tyArray__sMpvt1sOxOJ3LFGulnbeMQ T95_;
						nimZeroMem((void*)T95_, sizeof(tyArray__sMpvt1sOxOJ3LFGulnbeMQ));
						T95_[0] = copyString(loc);
						T95_[1] = copyString(title);
						T95_[2] = copyString(s);
						T95_[3] = copyString(kindmsg);
						writeLine__45Em82MGXqv9biomV0DEbSgio(__stderrp, T95_, 4);
					}
					LA90_: ;
				}
				goto LA65_;
				LA84_: ;
				LA65_: ;
				{
					NIM_BOOL T98_;
					NIM_BOOL T100_;
					T98_ = (NIM_BOOL)0;
					T98_ = hasHint__zh6OC34d9cPUHXjZ4qVA9bkw_2(conf, ((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) 74));
					if (!(T98_)) goto LA99_;
					T100_ = (NIM_BOOL)0;
					T100_ = eqeq___59bygf5b7AsTVb9a1lVM66oA(info, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg);
					T98_ = !(T100_);
					LA99_: ;
					if (!T98_) goto LA101_;
					writeSurroundingSrc__9aRUSlnze6Qb3IwHkkQ9bv6g(conf, info);
				}
				LA101_: ;
				{
					if (!(((*conf).mainPackageNotes[(NU)((((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) 83)- 12))>>3] &(1U<<((NU)((((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) 83)- 12))&7U)))!=0)) goto LA105_;
					{
						tyArray__24KAM9afIUgUaqBaEBB6r9bg T111_;
						NimStringDesc* T112_;
						if (!!(((*conf).writelnHook.ClP_0 == 0))) goto LA109_;
						nimZeroMem((void*)T111_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
						T111_[0] = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(info2);
						T111_[1] = copyString(((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_26));
						T111_[2] = nsuFormatSingleElem(((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_18), ((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_27));
						T112_ = (NimStringDesc*)0;
						T112_ = concat__9brDhFFC9aYh4TjJmoPfzOdw(T111_, 3);
						(*conf).writelnHook.ClE_0? (*conf).writelnHook.ClP_0(T112_, (*conf).writelnHook.ClE_0):((TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_28)((*conf).writelnHook.ClP_0))(T112_);
					}
					goto LA107_;
					LA109_: ;
					{
						if (!(((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 23))&63U)))!=0)) goto LA114_;
						{
							tyArray__24KAM9afIUgUaqBaEBB6r9bg T124_;
							if (!(((*conf).m.errorOutputs &((NU8)1<<((NU)(((tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA) 0))&7U)))!=0)) goto LA118_;
							{
								if (!(*conf).lastMsgWasDot) goto LA122_;
								(*conf).lastMsgWasDot = NIM_FALSE;
								write__PArlm09bKklm2BLsCg6YtaA(__stdoutp, ((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_14));
							}
							LA122_: ;
							nimZeroMem((void*)T124_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
							T124_[0] = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(info2);
							T124_[1] = copyString(((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_26));
							T124_[2] = nsuFormatSingleElem(((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_18), ((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_27));
							writeLine__45Em82MGXqv9biomV0DEbSgio(__stdoutp, T124_, 3);
							flushFile__fU6ZlJAtQ9bre04EDZLdGsA_2(__stdoutp);
						}
						LA118_: ;
					}
					goto LA107_;
					LA114_: ;
					{
						if (!(((*conf).m.errorOutputs &((NU8)1<<((NU)(((tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA) 1))&7U)))!=0)) goto LA126_;
						{
							if (!(*conf).lastMsgWasDot) goto LA130_;
							(*conf).lastMsgWasDot = NIM_FALSE;
							write__PArlm09bKklm2BLsCg6YtaA(__stderrp, ((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_14));
						}
						LA130_: ;
						{
							NimStringDesc* T136_;
							NimStringDesc* T137_;
							if (!(((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 21))&63U)))!=0)) goto LA134_;
							setStyle__y8lW2LrW2n5ZHaxH9bAf4WA(__stderrp, 1);
							T136_ = (NimStringDesc*)0;
							T136_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(info2);
							write__PArlm09bKklm2BLsCg6YtaA(__stderrp, T136_);
							resetAttributes__6J8xlU57R8cS9bLzTS89aM5g(__stderrp);
							write__PArlm09bKklm2BLsCg6YtaA(__stderrp, ((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_26));
							setForegroundColor__vJutklhcnQq9akCXxcuSHAg(__stderrp, ((tyEnum_ForegroundColor__ez9ah4IgQc0AbdW68acioDg) 36), NIM_FALSE);
							T137_ = (NimStringDesc*)0;
							T137_ = nsuFormatSingleElem(((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_18), ((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_27));
							write__PArlm09bKklm2BLsCg6YtaA(__stderrp, T137_);
							resetAttributes__6J8xlU57R8cS9bLzTS89aM5g(__stderrp);
							resetAttributes__6J8xlU57R8cS9bLzTS89aM5g(__stderrp);
							write__PArlm09bKklm2BLsCg6YtaA(__stderrp, ((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_14));
						}
						goto LA132_;
						LA134_: ;
						{
							tyArray__24KAM9afIUgUaqBaEBB6r9bg T139_;
							nimZeroMem((void*)T139_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
							T139_[0] = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(info2);
							T139_[1] = copyString(((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_26));
							T139_[2] = nsuFormatSingleElem(((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_18), ((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_27));
							writeLine__45Em82MGXqv9biomV0DEbSgio(__stderrp, T139_, 3);
						}
						LA132_: ;
					}
					goto LA107_;
					LA126_: ;
					LA107_: ;
				}
				LA105_: ;
			}
			LA60_: ;
		}
		LA58_: ;
	}
	LA35_: ;
	handleError__T2cS0vBHloueESngIcrNPg(conf, msg, eh, s);
}
N_LIB_PRIVATE N_NIMCALL(void, listWarnings__O9arH9bYenXLOr27ZSmcQnEw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	msgWriteln__PO49anyWCbe63GYNOs9cVuvg(conf, ((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_33), 0);
	{
		tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w aX60gensym141_;
		NI res;
		aX60gensym141_ = (tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w)0;
		res = ((NI) 12);
		{
			while (1) {
				tyArray__Re75IspeoxXy2oCZHwcRrA T4_;
				NimStringDesc* T10_;
				if (!(res <= ((NI) 51))) goto LA3;
				aX60gensym141_ = ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) (res));
				nimZeroMem((void*)T4_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
				{
					if (!(((*conf).notes[(NU)((((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) (aX60gensym141_))- 12))>>3] &(1U<<((NU)((((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) (aX60gensym141_))- 12))&7U)))!=0)) goto LA7_;
					T4_[0] = copyString(((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_35));
				}
				goto LA5_;
				LA7_: ;
				{
					T4_[0] = copyString(((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_12));
				}
				LA5_: ;
				T4_[1] = reprEnum((NI)aX60gensym141_, (&NTI__29cbg2fC1z5iM1PAI28kR5w_));
				T10_ = (NimStringDesc*)0;
				T10_ = nsuFormatOpenArray(((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_34), T4_, 2);
				msgWriteln__PO49anyWCbe63GYNOs9cVuvg(conf, T10_, 0);
				res += ((NI) 1);
			} LA3: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, listHints__O9arH9bYenXLOr27ZSmcQnEw_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	msgWriteln__PO49anyWCbe63GYNOs9cVuvg(conf, ((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_36), 0);
	{
		tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w aX60gensym143_;
		NI res;
		aX60gensym143_ = (tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w)0;
		res = ((NI) 52);
		{
			while (1) {
				tyArray__Re75IspeoxXy2oCZHwcRrA T4_;
				NimStringDesc* T10_;
				if (!(res <= ((NI) 83))) goto LA3;
				aX60gensym143_ = ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) (res));
				nimZeroMem((void*)T4_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
				{
					if (!(((*conf).notes[(NU)((((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) (aX60gensym143_))- 12))>>3] &(1U<<((NU)((((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) (aX60gensym143_))- 12))&7U)))!=0)) goto LA7_;
					T4_[0] = copyString(((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_35));
				}
				goto LA5_;
				LA7_: ;
				{
					T4_[0] = copyString(((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_12));
				}
				LA5_: ;
				T4_[1] = reprEnum((NI)aX60gensym143_, (&NTI__29cbg2fC1z5iM1PAI28kR5w_));
				T10_ = (NimStringDesc*)0;
				T10_ = nsuFormatOpenArray(((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_34), T4_, 2);
				msgWriteln__PO49anyWCbe63GYNOs9cVuvg(conf, T10_, 0);
				res += ((NI) 1);
			} LA3: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, msgQuit__PlZXt6qHCDDk29c9ac4IuLGA)(NI8 x) {
	exit(((NI) (x)));
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q, newLineInfo__NPagzbOMpGo9aqJmfnDrITg)(NI32 fileInfoIdx, NI line, NI col) {
	tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q result;
	nimZeroMem((void*)(&result), sizeof(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q));
	result.fileIndex = fileInfoIdx;
	{
		if (!(line < ((NI) 65535))) goto LA3_;
		result.line = ((NU16) (line));
	}
	goto LA1_;
	LA3_: ;
	{
		result.line = ((NU16) 65535);
	}
	LA1_: ;
	{
		if (!(col < ((NI) 32767))) goto LA8_;
		result.col = ((NI16) (col));
	}
	goto LA6_;
	LA8_: ;
	{
		result.col = ((NI16) -1);
	}
	LA6_: ;
	return result;
}
static N_INLINE(void, shallow__cnzwaZQQIa73ryXE31wijQsystem)(NimStringDesc** s) {
	TGenericSeq* s_2;
	s_2 = ((TGenericSeq*) ((*s)));
	{
		NimStringDesc* T5_;
		if (!(s_2 == ((TGenericSeq*) NIM_NIL))) goto LA3_;
		T5_ = (NimStringDesc*)0;
		T5_ = mnewString(((NI) 0));
		s_2 = ((TGenericSeq*) (T5_));
	}
	LA3_: ;
	{
		if (!((NI)((*s_2).reserved & ((NI) IL64(4611686018427387904))) == ((NI) 0))) goto LA8_;
		(*s_2).reserved = (NI)((*s_2).reserved | ((NI) (IL64(-9223372036854775807) - IL64(1))));
	}
	LA8_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, canonicalCase__ieSCOeB9alirM2uC0jUt1Dg)(NimStringDesc** path) {
}
static N_INLINE(NF, toFloat__y1Fm9aHmxw9bS2jir137Fu5gsystem)(NI i) {
	NF result;
	result = (NF)0;
	result = ((NF) (i));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, toCChar__JTr4d3QfIoJwmoCY9bN9adqQ)(NIM_CHAR c, NimStringDesc** result) {
	switch (((NU8)(c))) {
	case 0 ... 31:
	case 127 ... 255:
	{
		NimStringDesc* T2_;
		unsureAsgnRef((void**) (&(*result)), addChar((*result), 92));
		T2_ = (NimStringDesc*)0;
		T2_ = nsuToOctal(c);
		unsureAsgnRef((void**) (&(*result)), resizeString((*result), (T2_ ? T2_->Sup.len : 0) + 0));
appendString((*result), T2_);
	}
	break;
	case 39:
	case 34:
	case 92:
	case 63:
	{
		unsureAsgnRef((void**) (&(*result)), addChar((*result), 92));
		unsureAsgnRef((void**) (&(*result)), addChar((*result), c));
	}
	break;
	default:
	{
		unsureAsgnRef((void**) (&(*result)), addChar((*result), c));
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, makeCString__vQJydtKy4Nf6bXPYtbmjtg)(NimStringDesc* s) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	NimStringDesc* res;
	NF T1_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	result = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
	T1_ = (NF)0;
	T1_ = toFloat__y1Fm9aHmxw9bS2jir137Fu5gsystem((s ? s->Sup.len : 0));
	res = rawNewString(((NI) ((NI)(((NI) (((NF)(T1_) * (NF)(1.1000000000000001e+00)))) + ((NI) 1)))));
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_38));
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = (s ? s->Sup.len : 0);
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA4;
				i = i_2;
				{
					if (!((NI)((NI)(i + ((NI) 1)) % ((NI) 64)) == ((NI) 0))) goto LA7_;
					res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_39));
				}
				LA7_: ;
				toCChar__JTr4d3QfIoJwmoCY9bN9adqQ(s->data[i], (&res));
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
	res = addChar(res, 34);
	T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T9_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
	add__IM4kcMNkkOLJtqdEqSxR8A(&result, T9_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, newFileInfo__H9aV055mSUDR4HgT7SX79aqA)(NimStringDesc* fullPath, NimStringDesc* projPath, tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw* Result) {
	unsureAsgnRef((void**)&(*Result).fullPath, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).projPath, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).shortName, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).quotedName, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).quotedFullName, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).lines, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).dirtyFile, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).hash, NIM_NIL);
	(*Result).dirty = 0;
	unsureAsgnRef((void**) (&(*Result).fullPath), copyString(fullPath));
	unsureAsgnRef((void**) (&(*Result).projPath), copyString(projPath));
	unsureAsgnRef((void**) (&(*Result).shortName), nosextractFilename(fullPath));
	unsureAsgnRef((void**) (&(*Result).quotedName), makeCString__vQJydtKy4Nf6bXPYtbmjtg((*Result).shortName));
	unsureAsgnRef((void**) (&(*Result).quotedFullName), makeCString__vQJydtKy4Nf6bXPYtbmjtg(fullPath));
	unsureAsgnRef((void**) (&(*Result).lines), NIM_NIL);
}
N_LIB_PRIVATE N_NIMCALL(NI32, fileInfoIdx__Eu6qwnWjBAlxk5Kd4AsfYg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* filename, NIM_BOOL* isKnownFile) {
	NI32 result;
	NimStringDesc* volatile canon;
	NIM_BOOL pseudoPath;
	TSafePoint TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_37;
	NimStringDesc* canon2;
	result = (NI32)0;
	canon = (NimStringDesc*)0;
	pseudoPath = NIM_FALSE;
	pushSafePoint(&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_37);
	TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_37.status = _setjmp(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_37.context);
	if (TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_37.status == 0) {
	canon = canonicalizePath__9bhgFqdEZM7DoX7p3U69bQEg(conf, filename);
	shallow__cnzwaZQQIa73ryXE31wijQsystem((&canon));
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTI__BeJgrOdDsczOwEWOZbRfKA_))) {
			TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_37.status = 0;
			canon = copyString(filename);
			pseudoPath = NIM_TRUE;
			popCurrentException();
		}
	}
	if (TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_37.status != 0) reraiseException();
	canon2 = (NimStringDesc*)0;
	forceCopy__9aS5wD8MwJoemnVo59bh54Sg((&canon2), canon);
	canonicalCase__ieSCOeB9alirM2uC0jUt1Dg((&canon2));
	{
		NIM_BOOL T5_;
		NI32* T8_;
		T5_ = (NIM_BOOL)0;
		T5_ = hasKey__V2bna9aem30Wfb1MT9bSnPzQ((*conf).m.filenameToIndexTbl, canon2);
		if (!T5_) goto LA6_;
		(*isKnownFile) = NIM_TRUE;
		T8_ = (NI32*)0;
		T8_ = X5BX5D___cYD9bwEY2FvxLm9bWq5KUhtA((&(*conf).m.filenameToIndexTbl), canon2);
		result = (*T8_);
	}
	goto LA3_;
	LA6_: ;
	{
		NI T10_;
		NimStringDesc* T11_;
		tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw T17_;
		NI T18_;
		(*isKnownFile) = NIM_FALSE;
		T10_ = ((*conf).m.fileInfos ? (*conf).m.fileInfos->Sup.len : 0);
		result = ((NI32) (T10_));
		T11_ = (NimStringDesc*)0;
		{
			if (!pseudoPath) goto LA14_;
			T11_ = copyString(filename);
		}
		goto LA12_;
		LA14_: ;
		{
			T11_ = relativeTo__zjjWvxBunys9bbBJHoqyLyQ(canon, (*conf).projectPath, 47);
		}
		LA12_: ;
		nimZeroMem((void*)(&T17_), sizeof(tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw));
		newFileInfo__H9aV055mSUDR4HgT7SX79aqA(canon, T11_, (&T17_));
		asgnRef((void**) (&(*conf).m.fileInfos), (tySequence__Zi9cGbCWofbtABoHJ5RbLNQ*) incrSeqV3((TGenericSeq*)((*conf).m.fileInfos), (&NTI__Zi9cGbCWofbtABoHJ5RbLNQ_)));
		T18_ = (*conf).m.fileInfos->Sup.len++;
		genericAssign((void*)(&(*conf).m.fileInfos->data[T18_]), (void*)(&T17_), (&NTI__GE3hAakXKOEpch4ap3zXAw_));
		X5BX5Deq___anizD9c0GXTQTVVON49cli6g((&(*conf).m.filenameToIndexTbl), canon2, result);
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI32, fileInfoIdx__3HRSVgYDcnQTolSZGx1zjA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* filename) {
	NI32 result;
	NIM_BOOL dummy;
	result = (NI32)0;
	dummy = (NIM_BOOL)0;
	result = fileInfoIdx__Eu6qwnWjBAlxk5Kd4AsfYg(conf, filename, (&dummy));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, setDirtyFile__fHp3umDqKLlqmAGYAQvEUA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NI32 fileIdx, NimStringDesc* filename) {
	NimStringDesc* T1_;
	T1_ = (NimStringDesc*)0;
	T1_ = (*conf).m.fileInfos->data[fileIdx].dirtyFile; (*conf).m.fileInfos->data[fileIdx].dirtyFile = copyStringRC1(filename);
	if (T1_) nimGCunrefNoCycle(T1_);
	asgnRef((void**) (&(*conf).m.fileInfos->data[fileIdx].lines), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) setLengthSeqV2(&((*conf).m.fileInfos->data[fileIdx].lines)->Sup, (&NTI__sM4lkSb7zS6F7OVMvW9cffQ_), ((NI) 0)));
}
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* errMsg, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2) {
{	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*conf).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 14));
		if (!(T3_)) goto LA4_;
		T3_ = ((*conf).structuredErrorHook.ClP_0 == 0);
		LA4_: ;
		if (!T3_) goto LA5_;
		goto BeforeRet_;
	}
	LA5_: ;
	writeContext__qseR1pyA8fYS6Wwflt2zAQ(conf, info);
	liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 1), errMsg, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 1), info2, NIM_FALSE);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, exactEquals__59bygf5b7AsTVb9a1lVM66oA_2)(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q a, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q b) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = (a.fileIndex == b.fileIndex);
	if (!(T2_)) goto LA3_;
	T2_ = (a.line == b.line);
	LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T1_ = (a.col == b.col);
	LA4_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, pushInfoContext__uDLK9aoAOWwwFTev4NOwF7Q)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* detail) {
	tyTuple__z822nu9bFF1AlQnLrHjdwpA T1_;
	NI T2_;
	NimStringDesc* T3_;
	nimZeroMem((void*)(&T1_), sizeof(tyTuple__z822nu9bFF1AlQnLrHjdwpA));
	T1_.Field0 = info;
	T1_.Field1 = copyString(detail);
	asgnRef((void**) (&(*conf).m.msgContext), (tySequence__tNFrR3kRuS1FSwuiLGoSSA*) incrSeqV3((TGenericSeq*)((*conf).m.msgContext), (&NTI__tNFrR3kRuS1FSwuiLGoSSA_)));
	T2_ = (*conf).m.msgContext->Sup.len++;
	(*conf).m.msgContext->data[T2_].Field0 = T1_.Field0;
	T3_ = (NimStringDesc*)0;
	T3_ = (*conf).m.msgContext->data[T2_].Field1; (*conf).m.msgContext->data[T2_].Field1 = copyStringRC1(T1_.Field1);
	if (T3_) nimGCunrefNoCycle(T3_);
}
N_LIB_PRIVATE N_NIMCALL(void, popInfoContext__O9arH9bYenXLOr27ZSmcQnEw_3)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	NI T1_;
	T1_ = ((*conf).m.msgContext ? (*conf).m.msgContext->Sup.len : 0);
	asgnRef((void**) (&(*conf).m.msgContext), (tySequence__tNFrR3kRuS1FSwuiLGoSSA*) setLengthSeqV2(&((*conf).m.msgContext)->Sup, (&NTI__tNFrR3kRuS1FSwuiLGoSSA_), ((NI) ((NI)(T1_ - ((NI) 1))))));
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___aQsiZUvE4SFfnWyKx1JgKA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	result = toFileLineCol__WM0LdwjY884aJ9cup7BS2vwmsgs(conf, info);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, suggestWriteln__NefEsy9c5k5U9cqqVIWMbpKg_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* s) {
	{
		if (!(((*conf).m.errorOutputs &((NU8)1<<((NU)(((tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA) 0))&7U)))!=0)) goto LA3_;
		{
			tyArray__nHXaesL0DJZHyVS07ARPRA T9_;
			if (!((*conf).writelnHook.ClP_0 == 0)) goto LA7_;
			nimZeroMem((void*)T9_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
			T9_[0] = copyString(s);
			writeLine__45Em82MGXqv9biomV0DEbSgio(__stdoutp, T9_, 1);
			flushFile__fU6ZlJAtQ9bre04EDZLdGsA_2(__stdoutp);
		}
		goto LA5_;
		LA7_: ;
		{
			(*conf).writelnHook.ClE_0? (*conf).writelnHook.ClP_0(s, (*conf).writelnHook.ClE_0):((TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_40)((*conf).writelnHook.ClP_0))(s);
		}
		LA5_: ;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, suggestQuit__5gyVlJxpO0KQGkItjZbJJg)(void) {
	tyObject_ESuggestDone__cDtWY9cE7zf8BAC5QcEZZkQ* T1_;
	NimStringDesc* T2_;
	T1_ = (tyObject_ESuggestDone__cDtWY9cE7zf8BAC5QcEZZkQ*)0;
	T1_ = (tyObject_ESuggestDone__cDtWY9cE7zf8BAC5QcEZZkQ*) newObj((&NTI__q2mvqo4oBiq6VrjsaIw7rg_), sizeof(tyObject_ESuggestDone__cDtWY9cE7zf8BAC5QcEZZkQ));
	(*T1_).Sup.Sup.Sup.Sup.m_type = (&NTI__cDtWY9cE7zf8BAC5QcEZZkQ_);
	(*T1_).Sup.Sup.Sup.name = "ESuggestDone";
	T2_ = (NimStringDesc*)0;
	T2_ = (*T1_).Sup.Sup.Sup.message; (*T1_).Sup.Sup.Sup.message = copyStringRC1(((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_41));
	if (T2_) nimGCunrefNoCycle(T2_);
	asgnRef((void**) (&(*T1_).Sup.Sup.Sup.parent), ((Exception*) NIM_NIL));
	raiseExceptionEx((Exception*)T1_, "ESuggestDone", "suggestQuit", "msgs.nim", 152);
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, formatMsg__1JLtPXtBEOA0aYSS8UEJDw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w msg, NimStringDesc* arg) {
	NimStringDesc* result;
	NimStringDesc* title;
	NimStringDesc* T4_;
	NimStringDesc* T5_;
	NimStringDesc* T6_;
	result = (NimStringDesc*)0;
	switch (msg) {
	case ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 12) ... ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 51):
	{
		title = copyString(((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_16));
	}
	break;
	case ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 52) ... ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 83):
	{
		title = copyString(((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_17));
	}
	break;
	default:
	{
		title = copyString(((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_15));
	}
	break;
	}
	T4_ = (NimStringDesc*)0;
	T5_ = (NimStringDesc*)0;
	T5_ = toFileLineCol__WM0LdwjY884aJ9cup7BS2vwmsgs(conf, info);
	T6_ = (NimStringDesc*)0;
	T6_ = getMessageStr__bApVJwLsexHv26MjGbKUvQ(msg, arg);
	T4_ = rawNewString((T5_ ? T5_->Sup.len : 0) + (title ? title->Sup.len : 0) + (T6_ ? T6_->Sup.len : 0) + 1);
appendString(T4_, T5_);
appendString(T4_, ((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_12));
appendString(T4_, title);
appendString(T4_, T6_);
	result = T4_;
	return result;
}
static N_INLINE(NIM_BOOL, lteqpercent___hPljn3JCDQ00ua1R07X9bxQ_2system)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) <= (NU64)(((NU) (y))));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q, getInfoContext__TXxF2CG3kwLqptPWf0kC9aQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NI index) {
	tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q result;
	NI i;
	nimZeroMem((void*)(&result), sizeof(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q));
	{
		NI T5_;
		if (!(index < ((NI) 0))) goto LA3_;
		T5_ = ((*conf).m.msgContext ? (*conf).m.msgContext->Sup.len : 0);
		i = (NI)(T5_ + index);
	}
	goto LA1_;
	LA3_: ;
	{
		i = index;
	}
	LA1_: ;
	{
		NI T9_;
		NIM_BOOL T10_;
		T9_ = ((*conf).m.msgContext ? (*conf).m.msgContext->Sup.len : 0);
		T10_ = (NIM_BOOL)0;
		T10_ = lteqpercent___hPljn3JCDQ00ua1R07X9bxQ_2system(T9_, i);
		if (!T10_) goto LA11_;
		result = unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg;
	}
	goto LA7_;
	LA11_: ;
	{
		result = (*conf).m.msgContext->data[i].Field0;
	}
	LA7_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, getInfoContextLen__QY5gXnIUBOUa79b5tGece0A)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	NI result;
	NI T1_;
{	result = (NI)0;
	T1_ = ((*conf).m.msgContext ? (*conf).m.msgContext->Sup.len : 0);
	result = T1_;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, setInfoContextLen__JRH1QeGlTzlBOChAZ7bvoQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NI L) {
	asgnRef((void**) (&(*conf).m.msgContext), (tySequence__tNFrR3kRuS1FSwuiLGoSSA*) setLengthSeqV2(&((*conf).m.msgContext)->Sup, (&NTI__tNFrR3kRuS1FSwuiLGoSSA_), ((NI) (L))));
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, quotedFilename__2Kbe7lBq9cqJa8J9cn4WRepg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q i) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		if (!(i.fileIndex < ((NI32) 0))) goto LA3_;
		result = makeCString__vQJydtKy4Nf6bXPYtbmjtg(((NimStringDesc*) &TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_7));
	}
	goto LA1_;
	LA3_: ;
	{
		if (!(((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 31))&63U)))!=0)) goto LA6_;
		result = (*conf).m.fileInfos->data[i.fileIndex].quotedFullName;
	}
	goto LA1_;
	LA6_: ;
	{
		result = (*conf).m.fileInfos->data[i.fileIndex].quotedName;
	}
	LA1_: ;
	return result;
}
